problemcaserun

package
v0.0.0-...-6882668 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the problemcaserun type in the database.
	Label = "problem_case_run"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldRepo holds the string denoting the repo field in the database.
	FieldRepo = "repo"
	// FieldBranch holds the string denoting the branch field in the database.
	FieldBranch = "branch"
	// FieldSuiteName holds the string denoting the suite_name field in the database.
	FieldSuiteName = "suite_name"
	// FieldCaseName holds the string denoting the case_name field in the database.
	FieldCaseName = "case_name"
	// FieldFlaky holds the string denoting the flaky field in the database.
	FieldFlaky = "flaky"
	// FieldTimecostMs holds the string denoting the timecost_ms field in the database.
	FieldTimecostMs = "timecost_ms"
	// FieldReportTime holds the string denoting the report_time field in the database.
	FieldReportTime = "report_time"
	// FieldBuildURL holds the string denoting the build_url field in the database.
	FieldBuildURL = "build_url"
	// FieldReason holds the string denoting the reason field in the database.
	FieldReason = "reason"
	// Table holds the table name of the problemcaserun in the database.
	Table = "problem_case_runs"
)

Variables

var (
	// DefaultFlaky holds the default value on creation for the "flaky" field.
	DefaultFlaky bool
	// BuildURLValidator is a validator for the "build_url" field. It is called by the builders before save.
	BuildURLValidator func(string) error
	// ReasonValidator is a validator for the "reason" field. It is called by the builders before save.
	ReasonValidator func(string) error
)

Columns holds all SQL columns for problemcaserun fields.

Functions

func And

And groups predicates with the AND operator between them.

func Branch

Branch applies equality check predicate on the "branch" field. It's identical to BranchEQ.

func BranchContains

func BranchContains(v string) predicate.ProblemCaseRun

BranchContains applies the Contains predicate on the "branch" field.

func BranchContainsFold

func BranchContainsFold(v string) predicate.ProblemCaseRun

BranchContainsFold applies the ContainsFold predicate on the "branch" field.

func BranchEQ

func BranchEQ(v string) predicate.ProblemCaseRun

BranchEQ applies the EQ predicate on the "branch" field.

func BranchEqualFold

func BranchEqualFold(v string) predicate.ProblemCaseRun

BranchEqualFold applies the EqualFold predicate on the "branch" field.

func BranchGT

func BranchGT(v string) predicate.ProblemCaseRun

BranchGT applies the GT predicate on the "branch" field.

func BranchGTE

func BranchGTE(v string) predicate.ProblemCaseRun

BranchGTE applies the GTE predicate on the "branch" field.

func BranchHasPrefix

func BranchHasPrefix(v string) predicate.ProblemCaseRun

BranchHasPrefix applies the HasPrefix predicate on the "branch" field.

func BranchHasSuffix

func BranchHasSuffix(v string) predicate.ProblemCaseRun

BranchHasSuffix applies the HasSuffix predicate on the "branch" field.

func BranchIn

func BranchIn(vs ...string) predicate.ProblemCaseRun

BranchIn applies the In predicate on the "branch" field.

func BranchLT

func BranchLT(v string) predicate.ProblemCaseRun

BranchLT applies the LT predicate on the "branch" field.

func BranchLTE

func BranchLTE(v string) predicate.ProblemCaseRun

BranchLTE applies the LTE predicate on the "branch" field.

func BranchNEQ

func BranchNEQ(v string) predicate.ProblemCaseRun

BranchNEQ applies the NEQ predicate on the "branch" field.

func BranchNotIn

func BranchNotIn(vs ...string) predicate.ProblemCaseRun

BranchNotIn applies the NotIn predicate on the "branch" field.

func BuildURL

func BuildURL(v string) predicate.ProblemCaseRun

BuildURL applies equality check predicate on the "build_url" field. It's identical to BuildURLEQ.

func BuildURLContains

func BuildURLContains(v string) predicate.ProblemCaseRun

BuildURLContains applies the Contains predicate on the "build_url" field.

func BuildURLContainsFold

func BuildURLContainsFold(v string) predicate.ProblemCaseRun

BuildURLContainsFold applies the ContainsFold predicate on the "build_url" field.

func BuildURLEQ

func BuildURLEQ(v string) predicate.ProblemCaseRun

BuildURLEQ applies the EQ predicate on the "build_url" field.

func BuildURLEqualFold

func BuildURLEqualFold(v string) predicate.ProblemCaseRun

BuildURLEqualFold applies the EqualFold predicate on the "build_url" field.

func BuildURLGT

func BuildURLGT(v string) predicate.ProblemCaseRun

BuildURLGT applies the GT predicate on the "build_url" field.

func BuildURLGTE

func BuildURLGTE(v string) predicate.ProblemCaseRun

BuildURLGTE applies the GTE predicate on the "build_url" field.

func BuildURLHasPrefix

func BuildURLHasPrefix(v string) predicate.ProblemCaseRun

BuildURLHasPrefix applies the HasPrefix predicate on the "build_url" field.

func BuildURLHasSuffix

func BuildURLHasSuffix(v string) predicate.ProblemCaseRun

BuildURLHasSuffix applies the HasSuffix predicate on the "build_url" field.

func BuildURLIn

func BuildURLIn(vs ...string) predicate.ProblemCaseRun

BuildURLIn applies the In predicate on the "build_url" field.

func BuildURLLT

func BuildURLLT(v string) predicate.ProblemCaseRun

BuildURLLT applies the LT predicate on the "build_url" field.

func BuildURLLTE

func BuildURLLTE(v string) predicate.ProblemCaseRun

BuildURLLTE applies the LTE predicate on the "build_url" field.

func BuildURLNEQ

func BuildURLNEQ(v string) predicate.ProblemCaseRun

BuildURLNEQ applies the NEQ predicate on the "build_url" field.

func BuildURLNotIn

func BuildURLNotIn(vs ...string) predicate.ProblemCaseRun

BuildURLNotIn applies the NotIn predicate on the "build_url" field.

func CaseName

func CaseName(v string) predicate.ProblemCaseRun

CaseName applies equality check predicate on the "case_name" field. It's identical to CaseNameEQ.

func CaseNameContains

func CaseNameContains(v string) predicate.ProblemCaseRun

CaseNameContains applies the Contains predicate on the "case_name" field.

func CaseNameContainsFold

func CaseNameContainsFold(v string) predicate.ProblemCaseRun

CaseNameContainsFold applies the ContainsFold predicate on the "case_name" field.

func CaseNameEQ

func CaseNameEQ(v string) predicate.ProblemCaseRun

CaseNameEQ applies the EQ predicate on the "case_name" field.

func CaseNameEqualFold

func CaseNameEqualFold(v string) predicate.ProblemCaseRun

CaseNameEqualFold applies the EqualFold predicate on the "case_name" field.

func CaseNameGT

func CaseNameGT(v string) predicate.ProblemCaseRun

CaseNameGT applies the GT predicate on the "case_name" field.

func CaseNameGTE

func CaseNameGTE(v string) predicate.ProblemCaseRun

CaseNameGTE applies the GTE predicate on the "case_name" field.

func CaseNameHasPrefix

func CaseNameHasPrefix(v string) predicate.ProblemCaseRun

CaseNameHasPrefix applies the HasPrefix predicate on the "case_name" field.

func CaseNameHasSuffix

func CaseNameHasSuffix(v string) predicate.ProblemCaseRun

CaseNameHasSuffix applies the HasSuffix predicate on the "case_name" field.

func CaseNameIn

func CaseNameIn(vs ...string) predicate.ProblemCaseRun

CaseNameIn applies the In predicate on the "case_name" field.

func CaseNameLT

func CaseNameLT(v string) predicate.ProblemCaseRun

CaseNameLT applies the LT predicate on the "case_name" field.

func CaseNameLTE

func CaseNameLTE(v string) predicate.ProblemCaseRun

CaseNameLTE applies the LTE predicate on the "case_name" field.

func CaseNameNEQ

func CaseNameNEQ(v string) predicate.ProblemCaseRun

CaseNameNEQ applies the NEQ predicate on the "case_name" field.

func CaseNameNotIn

func CaseNameNotIn(vs ...string) predicate.ProblemCaseRun

CaseNameNotIn applies the NotIn predicate on the "case_name" field.

func Flaky

func Flaky(v bool) predicate.ProblemCaseRun

Flaky applies equality check predicate on the "flaky" field. It's identical to FlakyEQ.

func FlakyEQ

func FlakyEQ(v bool) predicate.ProblemCaseRun

FlakyEQ applies the EQ predicate on the "flaky" field.

func FlakyNEQ

func FlakyNEQ(v bool) predicate.ProblemCaseRun

FlakyNEQ applies the NEQ predicate on the "flaky" field.

func ID

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.ProblemCaseRun

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.ProblemCaseRun

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.ProblemCaseRun

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.ProblemCaseRun

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.ProblemCaseRun

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.ProblemCaseRun

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.ProblemCaseRun

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.ProblemCaseRun

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func Reason

Reason applies equality check predicate on the "reason" field. It's identical to ReasonEQ.

func ReasonContains

func ReasonContains(v string) predicate.ProblemCaseRun

ReasonContains applies the Contains predicate on the "reason" field.

func ReasonContainsFold

func ReasonContainsFold(v string) predicate.ProblemCaseRun

ReasonContainsFold applies the ContainsFold predicate on the "reason" field.

func ReasonEQ

func ReasonEQ(v string) predicate.ProblemCaseRun

ReasonEQ applies the EQ predicate on the "reason" field.

func ReasonEqualFold

func ReasonEqualFold(v string) predicate.ProblemCaseRun

ReasonEqualFold applies the EqualFold predicate on the "reason" field.

func ReasonGT

func ReasonGT(v string) predicate.ProblemCaseRun

ReasonGT applies the GT predicate on the "reason" field.

func ReasonGTE

func ReasonGTE(v string) predicate.ProblemCaseRun

ReasonGTE applies the GTE predicate on the "reason" field.

func ReasonHasPrefix

func ReasonHasPrefix(v string) predicate.ProblemCaseRun

ReasonHasPrefix applies the HasPrefix predicate on the "reason" field.

func ReasonHasSuffix

func ReasonHasSuffix(v string) predicate.ProblemCaseRun

ReasonHasSuffix applies the HasSuffix predicate on the "reason" field.

func ReasonIn

func ReasonIn(vs ...string) predicate.ProblemCaseRun

ReasonIn applies the In predicate on the "reason" field.

func ReasonLT

func ReasonLT(v string) predicate.ProblemCaseRun

ReasonLT applies the LT predicate on the "reason" field.

func ReasonLTE

func ReasonLTE(v string) predicate.ProblemCaseRun

ReasonLTE applies the LTE predicate on the "reason" field.

func ReasonNEQ

func ReasonNEQ(v string) predicate.ProblemCaseRun

ReasonNEQ applies the NEQ predicate on the "reason" field.

func ReasonNotIn

func ReasonNotIn(vs ...string) predicate.ProblemCaseRun

ReasonNotIn applies the NotIn predicate on the "reason" field.

func Repo

Repo applies equality check predicate on the "repo" field. It's identical to RepoEQ.

func RepoContains

func RepoContains(v string) predicate.ProblemCaseRun

RepoContains applies the Contains predicate on the "repo" field.

func RepoContainsFold

func RepoContainsFold(v string) predicate.ProblemCaseRun

RepoContainsFold applies the ContainsFold predicate on the "repo" field.

func RepoEQ

RepoEQ applies the EQ predicate on the "repo" field.

func RepoEqualFold

func RepoEqualFold(v string) predicate.ProblemCaseRun

RepoEqualFold applies the EqualFold predicate on the "repo" field.

func RepoGT

RepoGT applies the GT predicate on the "repo" field.

func RepoGTE

func RepoGTE(v string) predicate.ProblemCaseRun

RepoGTE applies the GTE predicate on the "repo" field.

func RepoHasPrefix

func RepoHasPrefix(v string) predicate.ProblemCaseRun

RepoHasPrefix applies the HasPrefix predicate on the "repo" field.

func RepoHasSuffix

func RepoHasSuffix(v string) predicate.ProblemCaseRun

RepoHasSuffix applies the HasSuffix predicate on the "repo" field.

func RepoIn

func RepoIn(vs ...string) predicate.ProblemCaseRun

RepoIn applies the In predicate on the "repo" field.

func RepoLT

RepoLT applies the LT predicate on the "repo" field.

func RepoLTE

func RepoLTE(v string) predicate.ProblemCaseRun

RepoLTE applies the LTE predicate on the "repo" field.

func RepoNEQ

func RepoNEQ(v string) predicate.ProblemCaseRun

RepoNEQ applies the NEQ predicate on the "repo" field.

func RepoNotIn

func RepoNotIn(vs ...string) predicate.ProblemCaseRun

RepoNotIn applies the NotIn predicate on the "repo" field.

func ReportTime

func ReportTime(v time.Time) predicate.ProblemCaseRun

ReportTime applies equality check predicate on the "report_time" field. It's identical to ReportTimeEQ.

func ReportTimeEQ

func ReportTimeEQ(v time.Time) predicate.ProblemCaseRun

ReportTimeEQ applies the EQ predicate on the "report_time" field.

func ReportTimeGT

func ReportTimeGT(v time.Time) predicate.ProblemCaseRun

ReportTimeGT applies the GT predicate on the "report_time" field.

func ReportTimeGTE

func ReportTimeGTE(v time.Time) predicate.ProblemCaseRun

ReportTimeGTE applies the GTE predicate on the "report_time" field.

func ReportTimeIn

func ReportTimeIn(vs ...time.Time) predicate.ProblemCaseRun

ReportTimeIn applies the In predicate on the "report_time" field.

func ReportTimeLT

func ReportTimeLT(v time.Time) predicate.ProblemCaseRun

ReportTimeLT applies the LT predicate on the "report_time" field.

func ReportTimeLTE

func ReportTimeLTE(v time.Time) predicate.ProblemCaseRun

ReportTimeLTE applies the LTE predicate on the "report_time" field.

func ReportTimeNEQ

func ReportTimeNEQ(v time.Time) predicate.ProblemCaseRun

ReportTimeNEQ applies the NEQ predicate on the "report_time" field.

func ReportTimeNotIn

func ReportTimeNotIn(vs ...time.Time) predicate.ProblemCaseRun

ReportTimeNotIn applies the NotIn predicate on the "report_time" field.

func SuiteName

func SuiteName(v string) predicate.ProblemCaseRun

SuiteName applies equality check predicate on the "suite_name" field. It's identical to SuiteNameEQ.

func SuiteNameContains

func SuiteNameContains(v string) predicate.ProblemCaseRun

SuiteNameContains applies the Contains predicate on the "suite_name" field.

func SuiteNameContainsFold

func SuiteNameContainsFold(v string) predicate.ProblemCaseRun

SuiteNameContainsFold applies the ContainsFold predicate on the "suite_name" field.

func SuiteNameEQ

func SuiteNameEQ(v string) predicate.ProblemCaseRun

SuiteNameEQ applies the EQ predicate on the "suite_name" field.

func SuiteNameEqualFold

func SuiteNameEqualFold(v string) predicate.ProblemCaseRun

SuiteNameEqualFold applies the EqualFold predicate on the "suite_name" field.

func SuiteNameGT

func SuiteNameGT(v string) predicate.ProblemCaseRun

SuiteNameGT applies the GT predicate on the "suite_name" field.

func SuiteNameGTE

func SuiteNameGTE(v string) predicate.ProblemCaseRun

SuiteNameGTE applies the GTE predicate on the "suite_name" field.

func SuiteNameHasPrefix

func SuiteNameHasPrefix(v string) predicate.ProblemCaseRun

SuiteNameHasPrefix applies the HasPrefix predicate on the "suite_name" field.

func SuiteNameHasSuffix

func SuiteNameHasSuffix(v string) predicate.ProblemCaseRun

SuiteNameHasSuffix applies the HasSuffix predicate on the "suite_name" field.

func SuiteNameIn

func SuiteNameIn(vs ...string) predicate.ProblemCaseRun

SuiteNameIn applies the In predicate on the "suite_name" field.

func SuiteNameLT

func SuiteNameLT(v string) predicate.ProblemCaseRun

SuiteNameLT applies the LT predicate on the "suite_name" field.

func SuiteNameLTE

func SuiteNameLTE(v string) predicate.ProblemCaseRun

SuiteNameLTE applies the LTE predicate on the "suite_name" field.

func SuiteNameNEQ

func SuiteNameNEQ(v string) predicate.ProblemCaseRun

SuiteNameNEQ applies the NEQ predicate on the "suite_name" field.

func SuiteNameNotIn

func SuiteNameNotIn(vs ...string) predicate.ProblemCaseRun

SuiteNameNotIn applies the NotIn predicate on the "suite_name" field.

func TimecostMs

func TimecostMs(v int) predicate.ProblemCaseRun

TimecostMs applies equality check predicate on the "timecost_ms" field. It's identical to TimecostMsEQ.

func TimecostMsEQ

func TimecostMsEQ(v int) predicate.ProblemCaseRun

TimecostMsEQ applies the EQ predicate on the "timecost_ms" field.

func TimecostMsGT

func TimecostMsGT(v int) predicate.ProblemCaseRun

TimecostMsGT applies the GT predicate on the "timecost_ms" field.

func TimecostMsGTE

func TimecostMsGTE(v int) predicate.ProblemCaseRun

TimecostMsGTE applies the GTE predicate on the "timecost_ms" field.

func TimecostMsIn

func TimecostMsIn(vs ...int) predicate.ProblemCaseRun

TimecostMsIn applies the In predicate on the "timecost_ms" field.

func TimecostMsLT

func TimecostMsLT(v int) predicate.ProblemCaseRun

TimecostMsLT applies the LT predicate on the "timecost_ms" field.

func TimecostMsLTE

func TimecostMsLTE(v int) predicate.ProblemCaseRun

TimecostMsLTE applies the LTE predicate on the "timecost_ms" field.

func TimecostMsNEQ

func TimecostMsNEQ(v int) predicate.ProblemCaseRun

TimecostMsNEQ applies the NEQ predicate on the "timecost_ms" field.

func TimecostMsNotIn

func TimecostMsNotIn(vs ...int) predicate.ProblemCaseRun

TimecostMsNotIn applies the NotIn predicate on the "timecost_ms" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the ProblemCaseRun queries.

func ByBranch

func ByBranch(opts ...sql.OrderTermOption) OrderOption

ByBranch orders the results by the branch field.

func ByBuildURL

func ByBuildURL(opts ...sql.OrderTermOption) OrderOption

ByBuildURL orders the results by the build_url field.

func ByCaseName

func ByCaseName(opts ...sql.OrderTermOption) OrderOption

ByCaseName orders the results by the case_name field.

func ByFlaky

func ByFlaky(opts ...sql.OrderTermOption) OrderOption

ByFlaky orders the results by the flaky field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByReason

func ByReason(opts ...sql.OrderTermOption) OrderOption

ByReason orders the results by the reason field.

func ByRepo

func ByRepo(opts ...sql.OrderTermOption) OrderOption

ByRepo orders the results by the repo field.

func ByReportTime

func ByReportTime(opts ...sql.OrderTermOption) OrderOption

ByReportTime orders the results by the report_time field.

func BySuiteName

func BySuiteName(opts ...sql.OrderTermOption) OrderOption

BySuiteName orders the results by the suite_name field.

func ByTimecostMs

func ByTimecostMs(opts ...sql.OrderTermOption) OrderOption

ByTimecostMs orders the results by the timecost_ms field.

Jump to